Description
============
PyPEC aims at fitting PEC data with an graphical interface. 

In terminal enter the following command:

.. code-block:: bash

    python -m pypec 


A pdf version of the documentation can be found here 
:download:`pypec <../../build/latex/pypec.pdf>`. 
The source code can be viewed on 
`GitHub <http://www.github.com/MilanSkocic/PyPEC>`_.

How to install
=================

.. literalinclude:: ../../../INSTALL.txt
    :language: bash

Dependencies
==============

.. literalinclude:: ../../../requirements.txt

License
==========

.. literalinclude:: ../../../LICENSE.txt